@@ -15,9 +15,10 @@ from tuskar.api.controllers.v1.controller import Controller
 from tuskar.api.controllers.v1.data_center import DataCenterController
 from tuskar.api.controllers.v1.flavor import FlavorsController
 from tuskar.api.controllers.v1.node import NodesController
+from tuskar.api.controllers.v1.overcloud import OvercloudsController
 from tuskar.api.controllers.v1.rack import RacksController
 from tuskar.api.controllers.v1.resource_class import ResourceClassesController
 
 __all__ = (Controller, DataCenterController, FlavorsController,
-           RacksController, ResourceClassesController,
+           OvercloudsController, RacksController, ResourceClassesController,
            NodesController)
